ClassLikeReflection

Struct ClassLikeReflection 

pub struct ClassLikeReflection {
Show 17 fields pub attribute_reflections: Vec<AttributeReflection>, pub name: ClassLikeName, pub inheritance: InheritanceReflection, pub constants: HashMap<StringIdentifier, ClassLikeConstantReflection>, pub cases: HashMap<StringIdentifier, EnumCaseReflection>, pub properties: MemeberCollection<PropertyReflection>, pub methods: MemeberCollection<FunctionLikeReflection>, pub used_traits: HashSet<Name>, pub used_trait_names: HashMap<StringIdentifier, Name>, pub backing_type: Option<TypeReflection>, pub is_final: bool, pub is_readonly: bool, pub is_abstract: bool, pub is_anonymous: bool, pub span: Span, pub is_populated: bool, pub issues: IssueCollection,
}
Represents reflection data for a PHP class, interface, enum, or trait.

Fields

attribute_reflections: Vec<AttributeReflection>

Attributes (e.g., annotations) associated with the class-like entity.

name: ClassLikeName

The name of the class-like entity, such as its fully qualified name.

inheritance: InheritanceReflection

Inheritance information for the class-like entity, including parent classes and implemented interfaces.

constants: HashMap<StringIdentifier, ClassLikeConstantReflection>

Constants defined in the class-like entity.

cases: HashMap<StringIdentifier, EnumCaseReflection>

Enum cases defined in the class-like entity, if it is an enum.

properties: MemeberCollection<PropertyReflection>

Properties defined in the class-like entity.

methods: MemeberCollection<FunctionLikeReflection>

Methods defined in the class-like entity.

used_traits: HashSet<Name>

Traits used by the class-like entity.

used_trait_names: HashMap<StringIdentifier, Name>

Traits used by the class-like entity.

backing_type: Option<TypeReflection>

The backing type of the entity, used if it is an enum.

is_final: bool

Whether the class-like entity is declared as final.

is_readonly: bool

Whether the class-like entity is declared as readonly.

is_abstract: bool

Whether the class-like entity is declared as abstract.

is_anonymous: bool

Whether the entity is an anonymous class.

span: Span

The span in the source code where the class-like entity is declared.

is_populated: bool

Indicates whether the reflection is fully populated with all metadata.

issues: IssueCollection

Issues encountered while processing the class-like entity.

Implementations

Source

impl ClassLikeReflection

pub fn new(name: ClassLikeName, span: Span) -> Self

pub const fn is_trait(&self) -> bool

Checks if this class-like entity is a trait.

pub const fn is_interface(&self) -> bool

Checks if this class-like entity is an interface.

pub const fn is_class(&self) -> bool

Checks if this class-like entity is a class.

pub const fn is_enum(&self) -> bool

Checks if this class-like entity is an enum.

pub const fn is_anonymous_class(&self) -> bool

Checks if this class-like entity is a trait.