pub enum ArrayTypeKind {
Array {
non_empty: bool,
key: Box<TypeKind>,
value: Box<TypeKind>,
known_size: Option<usize>,
},
List {
non_empty: bool,
value: Box<TypeKind>,
known_size: Option<usize>,
},
CallableArray,
Shape(ArrayShape),
}Expand description
Represents array types, including specialized arrays like lists and shapes.
Variants
Array
An array with specified key and value types.
For example, array<string, int> represents an array with string keys and int values.
Fields
List
A list (array with integer keys starting from zero) with a specified value type.
For example, list<string> represents a list of strings.
Fields
CallableArray
A callable array, representing an array that can be called as a function.
Shape(ArrayShape)
An array shape with specified properties and optional additional properties.
For example, shape{ foo: string, bar: int, ... }.