pub enum CallableTypeKind {
Callable {
pure: bool,
templates: Vec<Template>,
parameters: Vec<CallableParameter>,
return_kind: Box<TypeKind>,
},
Closure {
pure: bool,
templates: Vec<Template>,
parameters: Vec<CallableParameter>,
return_kind: Box<TypeKind>,
},
}Expand description
Represents callable types, including functions, methods, and closures, with specified parameters and return types.
Variants
Callable
A callable type with specified parameters and return type.
For example, callable(string, int): bool represents a callable that accepts a string and an int and returns a bool.
Fields

parameters: Vec<CallableParameter>Closure
A closure type with specified parameters and return type.
For example, Closure(string, int): bool.