pub enum ScalarTypeKind {
Show 17 variants
Bool,
Integer {
min: Option<isize>,
max: Option<isize>,
},
Float,
String,
IntegerMask(Vec<isize>),
IntegerMaskOf(StringIdentifier, StringIdentifier),
ClassString(Option<StringIdentifier>),
TraitString,
EnumString,
CallableString,
NumericString,
LiteralString,
LiteralInt,
NonEmptyString,
ArrayKey,
Numeric,
Scalar,
}Expand description
Represents scalar types, including specialized scalar types with additional properties.
Variants
Bool
The bool type.
Integer
The int type.
The Option types represent inclusive minimum and maximum bounds.
Float
The float type.
String
The string type.
IntegerMask(Vec<isize>)
An integer mask, representing a union of integers formed by bitwise OR of the given values.
For example, int-mask<1, 2, 4> includes all combinations of these bits set.
IntegerMaskOf(StringIdentifier, StringIdentifier)
An integer mask of constants from a class.
For example, int-mask-of<Class, CONST_PREFIX_*> represents a mask using constants from Class with a given prefix.
ClassString(Option<StringIdentifier>)
A class string type, optionally specifying a class.
For example, class-string or class-string<Foo>, representing the name of a class as a string.
TraitString
A trait string type, representing the name of a trait as a string.
EnumString
An enum string type, representing the name of an enum as a string.
CallableString
A callable string type, representing a string that refers to a callable function or method.
NumericString
A numeric string type, representing a string that contains a numeric value.
LiteralString
A literal string type, representing strings known at compile time.
LiteralInt
A literal integer type, representing integers known at compile time.
NonEmptyString
A non-empty string type.
ArrayKey
The array-key type, representing values that can be used as array keys (int or string).
Numeric
The numeric type, representing either int or float.
Scalar
The scalar type, representing bool, int, float, or string.