pub fn variable_kind(name: StringIdentifier) -> TypeKindExpand description
Creates a TypeKind representing a variable type with the given name.
pub fn variable_kind(name: StringIdentifier) -> TypeKindCreates a TypeKind representing a variable type with the given name.